import React from 'react'
import { Link, useParams } from 'react-router-dom'

import Page from 'components/page'
import { useTranslation } from 'react-i18next'
import {
  Button,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Paper,
} from '@mui/material'
import { Guest } from 'interfaces'
import SponsorInfoButtons from 'routes/components/sponsorInfoButtons'
import format from 'date-fns/format'

type GuestInfoParams = {
  pid: string
}
interface RoleLineProps {
  guest: Guest
}

const RoleLine = ({ guest }: RoleLineProps) => {
  const [t, i18n] = useTranslation('common')
  return (
    <TableRow
      key={guest.id}
      sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
    >
      <TableCell align="left">
        {i18n.language === 'en' ? guest.role_en : guest.role_nb}
      </TableCell>
      <TableCell component="th" scope="row">
        {guest.start_date ? format(guest.start_date, 'yyyy-MM-dd') : null} -{' '}
        {format(guest.end_date, 'yyyy-MM-dd')}
      </TableCell>
      <TableCell align="left">
        {i18n.language === 'en' ? guest.ou_en : guest.ou_nb}
      </TableCell>
      <TableCell>
        <Button
          variant="contained"
          component={Link}
          to={`/sponsor/guest/${guest.pid}/roles/${guest.id}`}
        >
          {t('sponsor.choose')}
        </Button>
      </TableCell>
    </TableRow>
  )
}

interface GuestInfoProps {
  guests: Guest[]
}

export default function GuestInfo({ guests }: GuestInfoProps) {
  const { pid } = useParams<GuestInfoParams>()
  const [t] = useTranslation(['common'])

  const roles = guests.filter((guest) => guest.pid.toString() === pid)
  const guestInfo = roles[0]

  return (
    <Page>
      <SponsorInfoButtons to="/sponsor" />
      <h4>{t('sponsor.contactInfo')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('sponsor.contactInfo')}</TableCell>
              <TableCell />
            </TableRow>
          </TableHead>
          <TableBody>
            <TableRow>
              <TableCell align="left">{t('input.fullName')}</TableCell>
              <TableCell align="left">{guestInfo.name}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.email')}</TableCell>
              <TableCell align="left">{guestInfo.email}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.nationalIdNumber')}</TableCell>
              <TableCell align="left">{guestInfo.fnr}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.mobilePhone')}</TableCell>
              <TableCell align="left">{guestInfo.mobile}</TableCell>
            </TableRow>
          </TableBody>
        </Table>
      </TableContainer>
      <h4>{t('sponsor.roleInfo')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('common:role')}</TableCell>
              <TableCell align="left">{t('common:period')}</TableCell>
              <TableCell align="left">{t('common:ou')}</TableCell>
              <TableCell align="left">{t('common:choice')}</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {roles.map((guest) => (
              <RoleLine guest={guest} />
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </Page>
  )
}
