from drf_spectacular.utils import extend_schema, OpenApiParameter
from rest_framework import mixins
from rest_framework.viewsets import GenericViewSet, ModelViewSet

from greg.api.pagination import PrimaryKeyCursorPagination
from greg.api.serializers import PersonSerializer
from greg.api.serializers.sponsor import SponsorSerializer
from greg.models import Sponsor, Person


class SponsorViewSet(ModelViewSet):
    """Sponsor API"""

    queryset = Sponsor.objects.all().order_by("id")
    serializer_class = SponsorSerializer
    pagination_class = PrimaryKeyCursorPagination
    lookup_field = "id"


@extend_schema(
    parameters=[
        OpenApiParameter(
            name="sponsor_id",
            description="Sponsor ID",
            location=OpenApiParameter.PATH,
            required=True,
            type=int,
        )
    ]
)
class SponsorGuestsViewSet(mixins.ListModelMixin, GenericViewSet):
    queryset = Person.objects.all().order_by("id")
    serializer_class = PersonSerializer
    pagination_class = PrimaryKeyCursorPagination
    lookup_field = "id"

    def get_queryset(self):
        qs = self.queryset
        if not self.kwargs:
            return qs.none()
        sponsor_id = self.kwargs["sponsor_id"]
        qs = qs.filter(roles__sponsor_id=sponsor_id).order_by("id")
        return qs
