import datetime
from rest_framework import serializers

from greg.models import Role


class RoleSerializerUi(serializers.ModelSerializer):
    def update(self, instance, validated_data):
        # validate new date is after old date, and old date has not passed
        today = datetime.date.today()
        new_start = validated_data.get("start_date")
        new_end = validated_data.get("end_date")
        if new_start:
            new_start = datetime.datetime.strptime(
                validated_data["start_date"], "%Y-%m-%d"
            ).date()
            if new_start < today:
                raise serializers.ValidationError("Start date cannot be in the past")
            if instance.start_date < today and new_start:
                raise serializers.ValidationError(
                    "Role has started, cannot change start date"
                )
            instance.start_date = new_start
        if new_end:
            new_end = datetime.datetime.strptime(
                validated_data["end_date"], "%Y-%m-%d"
            ).date()
            if new_end < today:
                raise serializers.ValidationError("End date cannot be in the past")
            if instance.end_date < today and new_end:
                raise serializers.ValidationError(
                    "Role has ended, cannot change end date"
                )
            max_days = today + datetime.timedelta(days=instance.type.max_days)
            if new_end > max_days:
                raise serializers.ValidationError(
                    f"New end date too far into the future. Must be before {max_days.strftime('%Y-%m-%d')}"
                )
            instance.end_date = new_end

        return instance

    class Meta:
        model = Role
        fields = [
            "orgunit_id",
            "start_date",
            "type",
            "end_date",
            "contact_person_unit",
            "comments",
            "available_in_search",
        ]
