from django.db import transaction
from rest_framework import status
from rest_framework.authentication import BasicAuthentication, SessionAuthentication
from rest_framework.generics import GenericAPIView
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response

from greg.models import Role
from greg.permissions import IsSponsor
from gregui.api.serializers.role import RoleSerializerUi
from gregui.api.serializers.roletype import RoleTypeSerializerUi


class RoleInfoView(GenericAPIView):
    queryset = Role.objects.all()
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated, IsSponsor]
    serializer_class = RoleSerializerUi

    def patch(self, request, id):
        role = Role.objects.get(id=id)

        with transaction.atomic():
            serializer = self.serializer_class(
                instance=role, data=request.data, partial=True
            )
            serializer.is_valid(raise_exception=True)
            instance = serializer.update(role, request.data)
            instance.save()
        return Response(status=status.HTTP_200_OK)
